``baseplate.frameworks.queue_consumer``
=======================================

.. automodule:: baseplate.frameworks.queue_consumer

.. toctree::
   :titlesonly:

   baseplate.frameworks.queue_consumer.kafka: Kafka Queue Consumer <kafka>
   baseplate.frameworks.queue_consumer.kombu: Kombu Queue Consumer <kombu>
